
from emachinery.gui.consolewidget import ConsoleWidget
from emachinery.gui.mplwidget import MplWidget
from emachinery.gui.qcodeeditor import QCodeEditor

# from consolewidget import ConsoleWidget
# from mplwidget import MplWidget
# from qcodeeditor import QCodeEditor
# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainWindow_v2.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1712, 1215)
        MainWindow.setMinimumSize(QtCore.QSize(0, 0))
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.scrollArea_CBS_Left = QtWidgets.QScrollArea(self.centralwidget)
        self.scrollArea_CBS_Left.setStyleSheet("")
        self.scrollArea_CBS_Left.setWidgetResizable(True)
        self.scrollArea_CBS_Left.setObjectName("scrollArea_CBS_Left")
        self.scrollAreaWidgetContents_3 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_3.setGeometry(QtCore.QRect(0, 0, 842, 1154))
        self.scrollAreaWidgetContents_3.setObjectName("scrollAreaWidgetContents_3")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_3)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.tabWidget = QtWidgets.QTabWidget(self.scrollAreaWidgetContents_3)
        self.tabWidget.setMinimumSize(QtCore.QSize(500, 800))
        self.tabWidget.setStyleSheet("")
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.tab)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 10, 288, 218))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.comboBox_MachineType = QtWidgets.QComboBox(self.verticalLayoutWidget)
        self.comboBox_MachineType.setObjectName("comboBox_MachineType")
        self.comboBox_MachineType.addItem("")
        self.comboBox_MachineType.addItem("")
        self.verticalLayout.addWidget(self.comboBox_MachineType)
        self.comboBox_MachineName = QtWidgets.QComboBox(self.verticalLayoutWidget)
        self.comboBox_MachineName.setObjectName("comboBox_MachineName")
        self.verticalLayout.addWidget(self.comboBox_MachineName)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_npd = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_npd.setObjectName("label_npd")
        self.verticalLayout_2.addWidget(self.label_npd)
        self.label_npd_2 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_2.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_2.setObjectName("label_npd_2")
        self.verticalLayout_2.addWidget(self.label_npd_2)
        self.label_npd_3 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_3.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_3.setObjectName("label_npd_3")
        self.verticalLayout_2.addWidget(self.label_npd_3)
        self.label_npd_4 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_4.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_4.setObjectName("label_npd_4")
        self.verticalLayout_2.addWidget(self.label_npd_4)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lineEdit_npp = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_npp.setObjectName("lineEdit_npp")
        self.verticalLayout_3.addWidget(self.lineEdit_npp)
        self.lineEdit_RatedCurrent = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedCurrent.setObjectName("lineEdit_RatedCurrent")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedCurrent)
        self.lineEdit_RatedPower = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedPower.setObjectName("lineEdit_RatedPower")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedPower)
        self.lineEdit_RatedSpeed = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedSpeed.setObjectName("lineEdit_RatedSpeed")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedSpeed)
        self.horizontalLayout.addLayout(self.verticalLayout_3)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.pushButton_updateModel = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.pushButton_updateModel.setObjectName("pushButton_updateModel")
        self.horizontalLayout_4.addWidget(self.pushButton_updateModel)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.ConsoleWidget = ConsoleWidget(self.tab)
        self.ConsoleWidget.setEnabled(True)
        self.ConsoleWidget.setGeometry(QtCore.QRect(10, 220, 781, 661))
        self.ConsoleWidget.setObjectName("ConsoleWidget")
        self.label_pushedVariables = QtWidgets.QLabel(self.tab)
        self.label_pushedVariables.setGeometry(QtCore.QRect(330, 30, 471, 61))
        self.label_pushedVariables.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_pushedVariables.setWordWrap(True)
        self.label_pushedVariables.setObjectName("label_pushedVariables")
        self.label_pushedVariables0 = QtWidgets.QLabel(self.tab)
        self.label_pushedVariables0.setGeometry(QtCore.QRect(330, 10, 141, 16))
        self.label_pushedVariables0.setObjectName("label_pushedVariables0")
        self.tabWidget.addTab(self.tab, "")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_2.setGeometry(QtCore.QRect(0, 370, 811, 451))
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayoutWidget_8 = QtWidgets.QWidget(self.groupBox_2)
        self.verticalLayoutWidget_8.setGeometry(QtCore.QRect(10, 30, 791, 411))
        self.verticalLayoutWidget_8.setObjectName("verticalLayoutWidget_8")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_8)
        self.verticalLayout_16.setContentsMargins(2, 0, 2, 0)
        self.verticalLayout_16.setSpacing(1)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.label_qpix_CLKP = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_CLKP.setStyleSheet("background: rgb(0, 0, 0)")
        self.label_qpix_CLKP.setText("")
        self.label_qpix_CLKP.setScaledContents(False)
        self.label_qpix_CLKP.setObjectName("label_qpix_CLKP")
        self.verticalLayout_16.addWidget(self.label_qpix_CLKP)
        self.label_qpix_CLKI = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_CLKI.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_CLKI.setText("")
        self.label_qpix_CLKI.setScaledContents(False)
        self.label_qpix_CLKI.setObjectName("label_qpix_CLKI")
        self.verticalLayout_16.addWidget(self.label_qpix_CLKI)
        self.label_qpix_VLKP = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_VLKP.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_VLKP.setText("")
        self.label_qpix_VLKP.setScaledContents(False)
        self.label_qpix_VLKP.setObjectName("label_qpix_VLKP")
        self.verticalLayout_16.addWidget(self.label_qpix_VLKP)
        self.label_qpix_VLKI = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_VLKI.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_VLKI.setText("")
        self.label_qpix_VLKI.setScaledContents(False)
        self.label_qpix_VLKI.setObjectName("label_qpix_VLKI")
        self.verticalLayout_16.addWidget(self.label_qpix_VLKI)
        self.label_qpix_Note1 = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_Note1.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_Note1.setText("")
        self.label_qpix_Note1.setScaledContents(False)
        self.label_qpix_Note1.setObjectName("label_qpix_Note1")
        self.verticalLayout_16.addWidget(self.label_qpix_Note1)
        self.label_qpix_Note2 = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_Note2.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_Note2.setText("")
        self.label_qpix_Note2.setScaledContents(False)
        self.label_qpix_Note2.setObjectName("label_qpix_Note2")
        self.verticalLayout_16.addWidget(self.label_qpix_Note2)
        self.label_qpix_Note3 = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_Note3.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_Note3.setText("")
        self.label_qpix_Note3.setScaledContents(False)
        self.label_qpix_Note3.setObjectName("label_qpix_Note3")
        self.verticalLayout_16.addWidget(self.label_qpix_Note3)
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_3.setGeometry(QtCore.QRect(410, 240, 321, 131))
        self.groupBox_3.setObjectName("groupBox_3")
        self.formLayoutWidget_2 = QtWidgets.QWidget(self.groupBox_3)
        self.formLayoutWidget_2.setGeometry(QtCore.QRect(20, 20, 160, 100))
        self.formLayoutWidget_2.setObjectName("formLayoutWidget_2")
        self.formLayout_2 = QtWidgets.QFormLayout(self.formLayoutWidget_2)
        self.formLayout_2.setContentsMargins(0, 0, 0, 0)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_12 = QtWidgets.QLabel(self.formLayoutWidget_2)
        self.label_12.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_12.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_12.setObjectName("label_12")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_12)
        self.lineEdit_PC_currentKP = QtWidgets.QLineEdit(self.formLayoutWidget_2)
        self.lineEdit_PC_currentKP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_PC_currentKP.setReadOnly(True)
        self.lineEdit_PC_currentKP.setObjectName("lineEdit_PC_currentKP")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lineEdit_PC_currentKP)
        self.label_13 = QtWidgets.QLabel(self.formLayoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_13.sizePolicy().hasHeightForWidth())
        self.label_13.setSizePolicy(sizePolicy)
        self.label_13.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_13.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_13.setObjectName("label_13")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_13)
        self.lineEdit_PC_currentKI = QtWidgets.QLineEdit(self.formLayoutWidget_2)
        self.lineEdit_PC_currentKI.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_PC_currentKI.setReadOnly(True)
        self.lineEdit_PC_currentKI.setObjectName("lineEdit_PC_currentKI")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.lineEdit_PC_currentKI)
        self.label_14 = QtWidgets.QLabel(self.formLayoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_14.sizePolicy().hasHeightForWidth())
        self.label_14.setSizePolicy(sizePolicy)
        self.label_14.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_14.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_14.setObjectName("label_14")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_14)
        self.lineEdit_PC_speedKP = QtWidgets.QLineEdit(self.formLayoutWidget_2)
        self.lineEdit_PC_speedKP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_PC_speedKP.setReadOnly(True)
        self.lineEdit_PC_speedKP.setObjectName("lineEdit_PC_speedKP")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.lineEdit_PC_speedKP)
        self.label_15 = QtWidgets.QLabel(self.formLayoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_15.sizePolicy().hasHeightForWidth())
        self.label_15.setSizePolicy(sizePolicy)
        self.label_15.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_15.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_15.setObjectName("label_15")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_15)
        self.lineEdit_PC_speedKI = QtWidgets.QLineEdit(self.formLayoutWidget_2)
        self.lineEdit_PC_speedKI.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_PC_speedKI.setReadOnly(True)
        self.lineEdit_PC_speedKI.setObjectName("lineEdit_PC_speedKI")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.lineEdit_PC_speedKI)
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_4.setGeometry(QtCore.QRect(410, 20, 321, 211))
        self.groupBox_4.setObjectName("groupBox_4")
        self.formLayoutWidget = QtWidgets.QWidget(self.groupBox_4)
        self.formLayoutWidget.setGeometry(QtCore.QRect(10, 20, 282, 176))
        self.formLayoutWidget.setObjectName("formLayoutWidget")
        self.formLayout = QtWidgets.QFormLayout(self.formLayoutWidget)
        self.formLayout.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout.setFormAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.formLayout.setContentsMargins(0, 0, 0, 0)
        self.formLayout.setHorizontalSpacing(6)
        self.formLayout.setObjectName("formLayout")
        self.label_7 = QtWidgets.QLabel(self.formLayoutWidget)
        font = QtGui.QFont()
        font.setItalic(False)
        self.label_7.setFont(font)
        self.label_7.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_7.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_7.setTextFormat(QtCore.Qt.AutoText)
        self.label_7.setAlignment(QtCore.Qt.AlignCenter)
        self.label_7.setObjectName("label_7")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.lineEdit_CLBW = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_CLBW.setFrame(True)
        self.lineEdit_CLBW.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_CLBW.setReadOnly(True)
        self.lineEdit_CLBW.setObjectName("lineEdit_CLBW")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lineEdit_CLBW)
        self.label_10 = QtWidgets.QLabel(self.formLayoutWidget)
        self.label_10.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_10.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_10.setObjectName("label_10")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_10)
        self.lineEdit_currentKP = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_currentKP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_currentKP.setReadOnly(True)
        self.lineEdit_currentKP.setObjectName("lineEdit_currentKP")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.lineEdit_currentKP)
        self.label_11 = QtWidgets.QLabel(self.formLayoutWidget)
        self.label_11.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_11.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_11.setObjectName("label_11")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.lineEdit_currentKI = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_currentKI.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_currentKI.setReadOnly(True)
        self.lineEdit_currentKI.setObjectName("lineEdit_currentKI")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.lineEdit_currentKI)
        self.label_8 = QtWidgets.QLabel(self.formLayoutWidget)
        self.label_8.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_8.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_8.setObjectName("label_8")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.lineEdit_speedKP = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_speedKP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_speedKP.setReadOnly(True)
        self.lineEdit_speedKP.setObjectName("lineEdit_speedKP")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.lineEdit_speedKP)
        self.label_9 = QtWidgets.QLabel(self.formLayoutWidget)
        self.label_9.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_9.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_9.setObjectName("label_9")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.lineEdit_speedKI = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_speedKI.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_speedKI.setReadOnly(True)
        self.lineEdit_speedKI.setObjectName("lineEdit_speedKI")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.lineEdit_speedKI)
        self.label_16 = QtWidgets.QLabel(self.formLayoutWidget)
        font = QtGui.QFont()
        font.setItalic(False)
        self.label_16.setFont(font)
        self.label_16.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_16.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_16.setTextFormat(QtCore.Qt.AutoText)
        self.label_16.setAlignment(QtCore.Qt.AlignCenter)
        self.label_16.setObjectName("label_16")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_16)
        self.lineEdit_designedVLBW = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_designedVLBW.setFrame(True)
        self.lineEdit_designedVLBW.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_designedVLBW.setReadOnly(True)
        self.lineEdit_designedVLBW.setObjectName("lineEdit_designedVLBW")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.lineEdit_designedVLBW)
        self.groupBox_5 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_5.setGeometry(QtCore.QRect(20, 20, 351, 121))
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayoutWidget_9 = QtWidgets.QWidget(self.groupBox_5)
        self.verticalLayoutWidget_9.setGeometry(QtCore.QRect(10, 20, 321, 91))
        self.verticalLayoutWidget_9.setObjectName("verticalLayoutWidget_9")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_9)
        self.verticalLayout_17.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_math_delta = QtWidgets.QLabel(self.verticalLayoutWidget_9)
        font = QtGui.QFont()
        font.setItalic(False)
        self.label_math_delta.setFont(font)
        self.label_math_delta.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_math_delta.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_math_delta.setTextFormat(QtCore.Qt.AutoText)
        self.label_math_delta.setAlignment(QtCore.Qt.AlignCenter)
        self.label_math_delta.setObjectName("label_math_delta")
        self.horizontalLayout_9.addWidget(self.label_math_delta)
        self.lineEdit_dampingFactor_delta = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.lineEdit_dampingFactor_delta.setFrame(True)
        self.lineEdit_dampingFactor_delta.setObjectName("lineEdit_dampingFactor_delta")
        self.horizontalLayout_9.addWidget(self.lineEdit_dampingFactor_delta)
        self.verticalLayout_17.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.label_desiredVLBW = QtWidgets.QLabel(self.verticalLayoutWidget_9)
        self.label_desiredVLBW.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_desiredVLBW.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_desiredVLBW.setObjectName("label_desiredVLBW")
        self.horizontalLayout_21.addWidget(self.label_desiredVLBW)
        self.lineEdit_desiredVLBW = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.lineEdit_desiredVLBW.setObjectName("lineEdit_desiredVLBW")
        self.horizontalLayout_21.addWidget(self.lineEdit_desiredVLBW)
        self.verticalLayout_17.addLayout(self.horizontalLayout_21)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem2)
        self.pushButton_pidTuner = QtWidgets.QPushButton(self.verticalLayoutWidget_9)
        self.pushButton_pidTuner.setObjectName("pushButton_pidTuner")
        self.horizontalLayout_16.addWidget(self.pushButton_pidTuner)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem3)
        self.verticalLayout_17.addLayout(self.horizontalLayout_16)
        self.tabWidget.addTab(self.tab_5, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.verticalLayoutWidget_4 = QtWidgets.QWidget(self.tab_4)
        self.verticalLayoutWidget_4.setGeometry(QtCore.QRect(10, 10, 361, 291))
        self.verticalLayoutWidget_4.setObjectName("verticalLayoutWidget_4")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_4)
        self.verticalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_4 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_11.addWidget(self.label_4)
        self.lineEdit_RO_MachineName = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_RO_MachineName.setReadOnly(True)
        self.lineEdit_RO_MachineName.setObjectName("lineEdit_RO_MachineName")
        self.horizontalLayout_11.addWidget(self.lineEdit_RO_MachineName)
        self.verticalLayout_7.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.label_EndTime = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_EndTime.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_EndTime.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_EndTime.setObjectName("label_EndTime")
        self.verticalLayout_8.addWidget(self.label_EndTime)
        self.label_CLTS = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_CLTS.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_CLTS.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_CLTS.setObjectName("label_CLTS")
        self.verticalLayout_8.addWidget(self.label_CLTS)
        self.label_VLTS = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_VLTS.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_VLTS.setObjectName("label_VLTS")
        self.verticalLayout_8.addWidget(self.label_VLTS)
        self.label_npd_12 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_npd_12.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_12.setObjectName("label_npd_12")
        self.verticalLayout_8.addWidget(self.label_npd_12)
        self.label_npd_13 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_npd_13.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_13.setObjectName("label_npd_13")
        self.verticalLayout_8.addWidget(self.label_npd_13)
        self.label_npd_15 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_npd_15.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_15.setObjectName("label_npd_15")
        self.verticalLayout_8.addWidget(self.label_npd_15)
        self.label_npd_14 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_npd_14.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_14.setObjectName("label_npd_14")
        self.verticalLayout_8.addWidget(self.label_npd_14)
        self.horizontalLayout_12.addLayout(self.verticalLayout_8)
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.lineEdit_EndTime = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_EndTime.setObjectName("lineEdit_EndTime")
        self.verticalLayout_9.addWidget(self.lineEdit_EndTime)
        self.lineEdit_CLTS = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_CLTS.setObjectName("lineEdit_CLTS")
        self.verticalLayout_9.addWidget(self.lineEdit_CLTS)
        self.lineEdit_VLTS = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_VLTS.setObjectName("lineEdit_VLTS")
        self.verticalLayout_9.addWidget(self.lineEdit_VLTS)
        self.lineEdit_LoadTorque = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_LoadTorque.setObjectName("lineEdit_LoadTorque")
        self.verticalLayout_9.addWidget(self.lineEdit_LoadTorque)
        self.lineEdit_LoadInertiaPercentage = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_LoadInertiaPercentage.setObjectName("lineEdit_LoadInertiaPercentage")
        self.verticalLayout_9.addWidget(self.lineEdit_LoadInertiaPercentage)
        self.lineEdit_ViscousCoefficient = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_ViscousCoefficient.setObjectName("lineEdit_ViscousCoefficient")
        self.verticalLayout_9.addWidget(self.lineEdit_ViscousCoefficient)
        self.lineEdit_OutputDataFileName = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_OutputDataFileName.setObjectName("lineEdit_OutputDataFileName")
        self.verticalLayout_9.addWidget(self.lineEdit_OutputDataFileName)
        self.horizontalLayout_12.addLayout(self.verticalLayout_9)
        self.verticalLayout_7.addLayout(self.horizontalLayout_12)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem4)
        self.pushButton_runCBasedSimulation = QtWidgets.QPushButton(self.verticalLayoutWidget_4)
        self.pushButton_runCBasedSimulation.setObjectName("pushButton_runCBasedSimulation")
        self.horizontalLayout_14.addWidget(self.pushButton_runCBasedSimulation)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem5)
        self.verticalLayout_7.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem6)
        self.pushButton_ACMPlotHere = QtWidgets.QPushButton(self.verticalLayoutWidget_4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.pushButton_ACMPlotHere.setFont(font)
        self.pushButton_ACMPlotHere.setObjectName("pushButton_ACMPlotHere")
        self.horizontalLayout_17.addWidget(self.pushButton_ACMPlotHere)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem7)
        self.pushButton_ACMPlotSeparate = QtWidgets.QPushButton(self.verticalLayoutWidget_4)
        self.pushButton_ACMPlotSeparate.setObjectName("pushButton_ACMPlotSeparate")
        self.horizontalLayout_17.addWidget(self.pushButton_ACMPlotSeparate)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem8)
        self.verticalLayout_7.addLayout(self.horizontalLayout_17)
        self.horizontalLayoutWidget_2 = QtWidgets.QWidget(self.tab_4)
        self.horizontalLayoutWidget_2.setGeometry(QtCore.QRect(390, 20, 381, 22))
        self.horizontalLayoutWidget_2.setObjectName("horizontalLayoutWidget_2")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_2)
        self.horizontalLayout_15.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.label__path2boptPython_2 = QtWidgets.QLabel(self.horizontalLayoutWidget_2)
        self.label__path2boptPython_2.setFrameShape(QtWidgets.QFrame.Panel)
        self.label__path2boptPython_2.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label__path2boptPython_2.setObjectName("label__path2boptPython_2")
        self.horizontalLayout_15.addWidget(self.label__path2boptPython_2)
        self.lineEdit_path2acmsimc = QtWidgets.QLineEdit(self.horizontalLayoutWidget_2)
        self.lineEdit_path2acmsimc.setObjectName("lineEdit_path2acmsimc")
        self.horizontalLayout_15.addWidget(self.lineEdit_path2acmsimc)
        self.verticalLayoutWidget_5 = QtWidgets.QWidget(self.tab_4)
        self.verticalLayoutWidget_5.setGeometry(QtCore.QRect(10, 310, 321, 481))
        self.verticalLayoutWidget_5.setObjectName("verticalLayoutWidget_5")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_5)
        self.verticalLayout_10.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.label__path2boptPython_3 = QtWidgets.QLabel(self.verticalLayoutWidget_5)
        self.label__path2boptPython_3.setFrameShape(QtWidgets.QFrame.Panel)
        self.label__path2boptPython_3.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label__path2boptPython_3.setObjectName("label__path2boptPython_3")
        self.horizontalLayout_19.addWidget(self.label__path2boptPython_3)
        self.lineEdit_path2ACMPlotLabels = QtWidgets.QLineEdit(self.verticalLayoutWidget_5)
        self.lineEdit_path2ACMPlotLabels.setReadOnly(True)
        self.lineEdit_path2ACMPlotLabels.setObjectName("lineEdit_path2ACMPlotLabels")
        self.horizontalLayout_19.addWidget(self.lineEdit_path2ACMPlotLabels)
        self.verticalLayout_10.addLayout(self.horizontalLayout_19)
        self.label_ACMLabels = QtWidgets.QLabel(self.verticalLayoutWidget_5)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_ACMLabels.setFont(font)
        self.label_ACMLabels.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.label_ACMLabels.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_ACMLabels.setAlignment(QtCore.Qt.AlignCenter)
        self.label_ACMLabels.setObjectName("label_ACMLabels")
        self.verticalLayout_10.addWidget(self.label_ACMLabels)
        self.plainTextEdit_ACMPlotLabels = QCodeEditor(self.verticalLayoutWidget_5)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.plainTextEdit_ACMPlotLabels.setFont(font)
        self.plainTextEdit_ACMPlotLabels.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.plainTextEdit_ACMPlotLabels.setObjectName("plainTextEdit_ACMPlotLabels")
        self.verticalLayout_10.addWidget(self.plainTextEdit_ACMPlotLabels)
        self.verticalLayoutWidget_6 = QtWidgets.QWidget(self.tab_4)
        self.verticalLayoutWidget_6.setGeometry(QtCore.QRect(340, 310, 451, 481))
        self.verticalLayoutWidget_6.setObjectName("verticalLayoutWidget_6")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_6)
        self.verticalLayout_13.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.label__path2boptPython_4 = QtWidgets.QLabel(self.verticalLayoutWidget_6)
        self.label__path2boptPython_4.setFrameShape(QtWidgets.QFrame.Panel)
        self.label__path2boptPython_4.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label__path2boptPython_4.setObjectName("label__path2boptPython_4")
        self.horizontalLayout_20.addWidget(self.label__path2boptPython_4)
        self.lineEdit_path2ACMPlotSignals = QtWidgets.QLineEdit(self.verticalLayoutWidget_6)
        self.lineEdit_path2ACMPlotSignals.setReadOnly(True)
        self.lineEdit_path2ACMPlotSignals.setObjectName("lineEdit_path2ACMPlotSignals")
        self.horizontalLayout_20.addWidget(self.lineEdit_path2ACMPlotSignals)
        self.verticalLayout_13.addLayout(self.horizontalLayout_20)
        self.label_ACMLabels_2 = QtWidgets.QLabel(self.verticalLayoutWidget_6)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_ACMLabels_2.setFont(font)
        self.label_ACMLabels_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.label_ACMLabels_2.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_ACMLabels_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_ACMLabels_2.setObjectName("label_ACMLabels_2")
        self.verticalLayout_13.addWidget(self.label_ACMLabels_2)
        self.plainTextEdit_ACMPlotDetails = QCodeEditor(self.verticalLayoutWidget_6)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.plainTextEdit_ACMPlotDetails.setFont(font)
        self.plainTextEdit_ACMPlotDetails.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.plainTextEdit_ACMPlotDetails.setObjectName("plainTextEdit_ACMPlotDetails")
        self.verticalLayout_13.addWidget(self.plainTextEdit_ACMPlotDetails)
        self.verticalLayoutWidget_7 = QtWidgets.QWidget(self.tab_4)
        self.verticalLayoutWidget_7.setGeometry(QtCore.QRect(450, 800, 341, 51))
        self.verticalLayoutWidget_7.setObjectName("verticalLayoutWidget_7")
        self.verticalLayout_CBSMplToolBar = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_7)
        self.verticalLayout_CBSMplToolBar.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_CBSMplToolBar.setObjectName("verticalLayout_CBSMplToolBar")
        self.groupBox = QtWidgets.QGroupBox(self.tab_4)
        self.groupBox.setGeometry(QtCore.QRect(390, 50, 401, 221))
        self.groupBox.setFlat(False)
        self.groupBox.setCheckable(False)
        self.groupBox.setObjectName("groupBox")
        self.gridLayoutWidget = QtWidgets.QWidget(self.groupBox)
        self.gridLayoutWidget.setGeometry(QtCore.QRect(0, 20, 391, 141))
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.gridLayoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setHorizontalSpacing(0)
        self.gridLayout.setVerticalSpacing(10)
        self.gridLayout.setObjectName("gridLayout")
        self.radioButton_Excitation_Velocity = QtWidgets.QRadioButton(self.gridLayoutWidget)
        self.radioButton_Excitation_Velocity.setObjectName("radioButton_Excitation_Velocity")
        self.gridLayout.addWidget(self.radioButton_Excitation_Velocity, 0, 1, 1, 1)
        self.radioButton_Excitation_SweepFrequency = QtWidgets.QRadioButton(self.gridLayoutWidget)
        self.radioButton_Excitation_SweepFrequency.setChecked(True)
        self.radioButton_Excitation_SweepFrequency.setObjectName("radioButton_Excitation_SweepFrequency")
        self.gridLayout.addWidget(self.radioButton_Excitation_SweepFrequency, 0, 2, 1, 1)
        self.radioButton_Excitation_Position = QtWidgets.QRadioButton(self.gridLayoutWidget)
        self.radioButton_Excitation_Position.setObjectName("radioButton_Excitation_Position")
        self.gridLayout.addWidget(self.radioButton_Excitation_Position, 0, 0, 1, 1)
        self.groupBox_sweepFrequency = QtWidgets.QGroupBox(self.gridLayoutWidget)
        self.groupBox_sweepFrequency.setEnabled(True)
        self.groupBox_sweepFrequency.setObjectName("groupBox_sweepFrequency")
        self.verticalLayoutWidget_10 = QtWidgets.QWidget(self.groupBox_sweepFrequency)
        self.verticalLayoutWidget_10.setGeometry(QtCore.QRect(10, 20, 113, 87))
        self.verticalLayoutWidget_10.setObjectName("verticalLayoutWidget_10")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_10)
        self.verticalLayout_14.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.radioButton_openLoop = QtWidgets.QRadioButton(self.verticalLayoutWidget_10)
        self.radioButton_openLoop.setAutoExclusive(False)
        self.radioButton_openLoop.setObjectName("radioButton_openLoop")
        self.verticalLayout_14.addWidget(self.radioButton_openLoop)
        self.radioButton_currentLoopOnly = QtWidgets.QRadioButton(self.verticalLayoutWidget_10)
        self.radioButton_currentLoopOnly.setAutoExclusive(False)
        self.radioButton_currentLoopOnly.setObjectName("radioButton_currentLoopOnly")
        self.verticalLayout_14.addWidget(self.radioButton_currentLoopOnly)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setSpacing(0)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label_maxFreq2Sweep = QtWidgets.QLabel(self.verticalLayoutWidget_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_maxFreq2Sweep.sizePolicy().hasHeightForWidth())
        self.label_maxFreq2Sweep.setSizePolicy(sizePolicy)
        self.label_maxFreq2Sweep.setObjectName("label_maxFreq2Sweep")
        self.horizontalLayout_13.addWidget(self.label_maxFreq2Sweep)
        self.lineEdit_maxFreq2Sweep = QtWidgets.QLineEdit(self.verticalLayoutWidget_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_maxFreq2Sweep.sizePolicy().hasHeightForWidth())
        self.lineEdit_maxFreq2Sweep.setSizePolicy(sizePolicy)
        self.lineEdit_maxFreq2Sweep.setObjectName("lineEdit_maxFreq2Sweep")
        self.horizontalLayout_13.addWidget(self.lineEdit_maxFreq2Sweep)
        self.verticalLayout_14.addLayout(self.horizontalLayout_13)
        self.gridLayout.addWidget(self.groupBox_sweepFrequency, 1, 2, 1, 1)
        self.tabWidget.addTab(self.tab_4, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.layoutWidget_2 = QtWidgets.QWidget(self.tab_6)
        self.layoutWidget_2.setGeometry(QtCore.QRect(240, 10, 311, 25))
        self.layoutWidget_2.setObjectName("layoutWidget_2")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(self.layoutWidget_2)
        self.horizontalLayout_22.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_22.addItem(spacerItem9)
        self.pushButton_bodePlot = QtWidgets.QPushButton(self.layoutWidget_2)
        self.pushButton_bodePlot.setObjectName("pushButton_bodePlot")
        self.horizontalLayout_22.addWidget(self.pushButton_bodePlot)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_22.addItem(spacerItem10)
        self.MplWidget_bodePlot = MplWidget(self.tab_6)
        self.MplWidget_bodePlot.setGeometry(QtCore.QRect(20, 40, 789, 837))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MplWidget_bodePlot.sizePolicy().hasHeightForWidth())
        self.MplWidget_bodePlot.setSizePolicy(sizePolicy)
        self.MplWidget_bodePlot.setObjectName("MplWidget_bodePlot")
        self.tabWidget.addTab(self.tab_6, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayoutWidget_2 = QtWidgets.QWidget(self.tab_2)
        self.verticalLayoutWidget_2.setGeometry(QtCore.QRect(0, 0, 791, 881))
        self.verticalLayoutWidget_2.setObjectName("verticalLayoutWidget_2")
        self.verticalLayout_inTab2 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_2)
        self.verticalLayout_inTab2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_inTab2.setObjectName("verticalLayout_inTab2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem11)
        self.pushButton_getSignal = QtWidgets.QPushButton(self.verticalLayoutWidget_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.pushButton_getSignal.setFont(font)
        self.pushButton_getSignal.setObjectName("pushButton_getSignal")
        self.horizontalLayout_2.addWidget(self.pushButton_getSignal)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem12)
        self.verticalLayout_inTab2.addLayout(self.horizontalLayout_2)
        self.MplWidget = MplWidget(self.verticalLayoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MplWidget.sizePolicy().hasHeightForWidth())
        self.MplWidget.setSizePolicy(sizePolicy)
        self.MplWidget.setObjectName("MplWidget")
        self.verticalLayout_inTab2.addWidget(self.MplWidget)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.verticalLayoutWidget_3 = QtWidgets.QWidget(self.tab_3)
        self.verticalLayoutWidget_3.setGeometry(QtCore.QRect(30, 420, 361, 248))
        self.verticalLayoutWidget_3.setObjectName("verticalLayoutWidget_3")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_3)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setObjectName("label")
        self.horizontalLayout_7.addWidget(self.label)
        self.comboBox_FEAConfig = QtWidgets.QComboBox(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_FEAConfig.sizePolicy().hasHeightForWidth())
        self.comboBox_FEAConfig.setSizePolicy(sizePolicy)
        self.comboBox_FEAConfig.setBaseSize(QtCore.QSize(0, 0))
        self.comboBox_FEAConfig.setObjectName("comboBox_FEAConfig")
        self.horizontalLayout_7.addWidget(self.comboBox_FEAConfig)
        self.verticalLayout_4.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_3 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_8.addWidget(self.label_3)
        self.comboBox_MachineSpec = QtWidgets.QComboBox(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_MachineSpec.sizePolicy().hasHeightForWidth())
        self.comboBox_MachineSpec.setSizePolicy(sizePolicy)
        self.comboBox_MachineSpec.setObjectName("comboBox_MachineSpec")
        self.horizontalLayout_8.addWidget(self.comboBox_MachineSpec)
        self.verticalLayout_4.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.label_npd_5 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_5.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_5.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_npd_5.setObjectName("label_npd_5")
        self.verticalLayout_5.addWidget(self.label_npd_5)
        self.label_npd_6 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_6.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_6.setObjectName("label_npd_6")
        self.verticalLayout_5.addWidget(self.label_npd_6)
        self.label_npd_7 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_7.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_7.setObjectName("label_npd_7")
        self.verticalLayout_5.addWidget(self.label_npd_7)
        self.label_npd_8 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_8.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_8.setObjectName("label_npd_8")
        self.verticalLayout_5.addWidget(self.label_npd_8)
        self.label_npd_9 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_9.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_9.setObjectName("label_npd_9")
        self.verticalLayout_5.addWidget(self.label_npd_9)
        self.horizontalLayout_3.addLayout(self.verticalLayout_5)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.lineEdit_npp_2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_npp_2.setObjectName("lineEdit_npp_2")
        self.verticalLayout_6.addWidget(self.lineEdit_npp_2)
        self.lineEdit_RatedCurrent_2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_RatedCurrent_2.setObjectName("lineEdit_RatedCurrent_2")
        self.verticalLayout_6.addWidget(self.lineEdit_RatedCurrent_2)
        self.lineEdit_RatedPower_2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_RatedPower_2.setObjectName("lineEdit_RatedPower_2")
        self.verticalLayout_6.addWidget(self.lineEdit_RatedPower_2)
        self.lineEdit_RatedSpeed_2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_RatedSpeed_2.setObjectName("lineEdit_RatedSpeed_2")
        self.verticalLayout_6.addWidget(self.lineEdit_RatedSpeed_2)
        self.lineEdit_RatedSpeed_3 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_RatedSpeed_3.setObjectName("lineEdit_RatedSpeed_3")
        self.verticalLayout_6.addWidget(self.lineEdit_RatedSpeed_3)
        self.horizontalLayout_3.addLayout(self.verticalLayout_6)
        self.verticalLayout_4.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem13 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem13)
        self.pushButton_updateModel_2 = QtWidgets.QPushButton(self.verticalLayoutWidget_3)
        self.pushButton_updateModel_2.setObjectName("pushButton_updateModel_2")
        self.horizontalLayout_5.addWidget(self.pushButton_updateModel_2)
        spacerItem14 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem14)
        self.verticalLayout_4.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        spacerItem15 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem15)
        self.pushButton_updateModel_4 = QtWidgets.QPushButton(self.verticalLayoutWidget_3)
        self.pushButton_updateModel_4.setObjectName("pushButton_updateModel_4")
        self.horizontalLayout_10.addWidget(self.pushButton_updateModel_4)
        spacerItem16 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem16)
        self.verticalLayout_4.addLayout(self.horizontalLayout_10)
        self.horizontalLayoutWidget = QtWidgets.QWidget(self.tab_3)
        self.horizontalLayoutWidget.setGeometry(QtCore.QRect(480, 30, 227, 22))
        self.horizontalLayoutWidget.setObjectName("horizontalLayoutWidget")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget)
        self.horizontalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label__path2boptPython = QtWidgets.QLabel(self.horizontalLayoutWidget)
        self.label__path2boptPython.setFrameShape(QtWidgets.QFrame.Panel)
        self.label__path2boptPython.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label__path2boptPython.setObjectName("label__path2boptPython")
        self.horizontalLayout_6.addWidget(self.label__path2boptPython)
        self.lineEdit_path2boptPython = QtWidgets.QLineEdit(self.horizontalLayoutWidget)
        self.lineEdit_path2boptPython.setObjectName("lineEdit_path2boptPython")
        self.horizontalLayout_6.addWidget(self.lineEdit_path2boptPython)
        self.tabWidget.addTab(self.tab_3, "")
        self.verticalLayout_12.addWidget(self.tabWidget)
        self.scrollArea_CBS_Left.setWidget(self.scrollAreaWidgetContents_3)
        self.horizontalLayout_18.addWidget(self.scrollArea_CBS_Left)
        self.scrollArea_2 = QtWidgets.QScrollArea(self.centralwidget)
        self.scrollArea_2.setMinimumSize(QtCore.QSize(0, 800))
        self.scrollArea_2.setWidgetResizable(True)
        self.scrollArea_2.setObjectName("scrollArea_2")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 842, 1154))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_2)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.MplWidget_ACMPlot = MplWidget(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MplWidget_ACMPlot.sizePolicy().hasHeightForWidth())
        self.MplWidget_ACMPlot.setSizePolicy(sizePolicy)
        self.MplWidget_ACMPlot.setMinimumSize(QtCore.QSize(800, 800))
        self.MplWidget_ACMPlot.setStyleSheet("background-color: rgb(170, 0, 127)")
        self.MplWidget_ACMPlot.setObjectName("MplWidget_ACMPlot")
        self.verticalLayout_11.addWidget(self.MplWidget_ACMPlot)
        self.scrollArea_2.setWidget(self.scrollAreaWidgetContents_2)
        self.horizontalLayout_18.addWidget(self.scrollArea_2)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1712, 21))
        self.menubar.setObjectName("menubar")
        self.menuLoad = QtWidgets.QMenu(self.menubar)
        self.menuLoad.setObjectName("menuLoad")
        self.menuTheme = QtWidgets.QMenu(self.menubar)
        self.menuTheme.setObjectName("menuTheme")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionLocate = QtWidgets.QAction(MainWindow)
        self.actionLocate.setObjectName("actionLocate")
        self.actionDark = QtWidgets.QAction(MainWindow)
        self.actionDark.setObjectName("actionDark")
        self.actionLight = QtWidgets.QAction(MainWindow)
        self.actionLight.setObjectName("actionLight")
        self.menuLoad.addAction(self.actionLocate)
        self.menuTheme.addAction(self.actionDark)
        self.menuTheme.addAction(self.actionLight)
        self.menubar.addAction(self.menuLoad.menuAction())
        self.menubar.addAction(self.menuTheme.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.comboBox_MachineType.setItemText(0, _translate("MainWindow", "Synchronous Machine"))
        self.comboBox_MachineType.setItemText(1, _translate("MainWindow", "Induction Machine"))
        self.label_npd.setText(_translate("MainWindow", "Number of Pole Pairs"))
        self.label_npd_2.setText(_translate("MainWindow", "Rated Current [Arms]"))
        self.label_npd_3.setText(_translate("MainWindow", "Rated Power [W]"))
        self.label_npd_4.setText(_translate("MainWindow", "Rated Speed [rpm]"))
        self.lineEdit_npp.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedCurrent.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedPower.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedSpeed.setText(_translate("MainWindow", "0"))
        self.pushButton_updateModel.setText(_translate("MainWindow", "Update Model"))
        self.label_pushedVariables.setText(_translate("MainWindow", "None"))
        self.label_pushedVariables0.setText(_translate("MainWindow", "Variables Pushed qtConsole: "))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Name Plate Data"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Theory"))
        self.groupBox_3.setTitle(_translate("MainWindow", "User Tuning"))
        self.label_12.setText(_translate("MainWindow", "上位机Current KP"))
        self.lineEdit_PC_currentKP.setText(_translate("MainWindow", "0"))
        self.label_13.setText(_translate("MainWindow", "上位机Current KI"))
        self.lineEdit_PC_currentKI.setText(_translate("MainWindow", "0"))
        self.label_14.setText(_translate("MainWindow", "上位机Speed KP"))
        self.lineEdit_PC_speedKP.setText(_translate("MainWindow", "0"))
        self.label_15.setText(_translate("MainWindow", "上位机Speed KI"))
        self.lineEdit_PC_speedKI.setText(_translate("MainWindow", "0"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Output"))
        self.label_7.setText(_translate("MainWindow", "Current Loop Bandwidth [Hz]"))
        self.lineEdit_CLBW.setText(_translate("MainWindow", "0"))
        self.label_10.setText(_translate("MainWindow", "Current KP"))
        self.lineEdit_currentKP.setText(_translate("MainWindow", "0"))
        self.label_11.setText(_translate("MainWindow", "Current KI"))
        self.lineEdit_currentKI.setText(_translate("MainWindow", "0"))
        self.label_8.setText(_translate("MainWindow", "Speed KP"))
        self.lineEdit_speedKP.setText(_translate("MainWindow", "0"))
        self.label_9.setText(_translate("MainWindow", "Speed KI"))
        self.lineEdit_speedKI.setText(_translate("MainWindow", "0"))
        self.label_16.setText(_translate("MainWindow", "Velocity Loop Bandwidth [Hz]"))
        self.lineEdit_designedVLBW.setText(_translate("MainWindow", "0"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Input"))
        self.label_math_delta.setText(_translate("MainWindow", "Dampling Factor δ [1]"))
        self.lineEdit_dampingFactor_delta.setText(_translate("MainWindow", "6.5"))
        self.label_desiredVLBW.setText(_translate("MainWindow", "Desired Velocity Loop Bandwidth [Hz]"))
        self.lineEdit_desiredVLBW.setText(_translate("MainWindow", "100"))
        self.pushButton_pidTuner.setText(_translate("MainWindow", "Get Output"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), _translate("MainWindow", "Controller Tuning"))
        self.label_4.setText(_translate("MainWindow", "Selected Machine Name"))
        self.label_EndTime.setText(_translate("MainWindow", "End Time [s]"))
        self.label_CLTS.setText(_translate("MainWindow", "Current Loop TS [1/Hz]"))
        self.label_VLTS.setText(_translate("MainWindow", "Velocity Loop TS [1/Hz]]"))
        self.label_npd_12.setText(_translate("MainWindow", "Load Torque [Nm]"))
        self.label_npd_13.setText(_translate("MainWindow", "Load Inertia Percentage [%]"))
        self.label_npd_15.setText(_translate("MainWindow", "Viscous Coefficient [Nm/elec.rad*s]"))
        self.label_npd_14.setText(_translate("MainWindow", "Output File Name Prefix@acmsimc"))
        self.lineEdit_EndTime.setText(_translate("MainWindow", "10"))
        self.lineEdit_CLTS.setText(_translate("MainWindow", "1/20e3"))
        self.lineEdit_VLTS.setText(_translate("MainWindow", "4/20e3"))
        self.lineEdit_LoadTorque.setText(_translate("MainWindow", "0.0"))
        self.lineEdit_LoadInertiaPercentage.setText(_translate("MainWindow", "16"))
        self.lineEdit_ViscousCoefficient.setText(_translate("MainWindow", "0.7e-4"))
        self.lineEdit_OutputDataFileName.setText(_translate("MainWindow", "PMSM_SweepFreq"))
        self.pushButton_runCBasedSimulation.setText(_translate("MainWindow", "Run Simulation"))
        self.pushButton_ACMPlotHere.setText(_translate("MainWindow", "Plot Here"))
        self.pushButton_ACMPlotSeparate.setText(_translate("MainWindow", "Plot in Separate Window"))
        self.label__path2boptPython_2.setText(_translate("MainWindow", "Path to acmsimc"))
        self.lineEdit_path2acmsimc.setText(_translate("MainWindow", "D:\\DrH\\Codes\\emachineryTestPYPI\\emachinery\\acmsimcv5"))
        self.label__path2boptPython_3.setText(_translate("MainWindow", "Path to plot labels file"))
        self.lineEdit_path2ACMPlotLabels.setText(_translate("MainWindow", "./plot_setting_files/labels.txt"))
        self.label_ACMLabels.setText(_translate("MainWindow", "Labels"))
        self.plainTextEdit_ACMPlotLabels.setPlainText(_translate("MainWindow", "None"))
        self.label__path2boptPython_4.setText(_translate("MainWindow", "Path to plot signals file"))
        self.lineEdit_path2ACMPlotSignals.setText(_translate("MainWindow", "./plot_setting_files/signals.txt"))
        self.label_ACMLabels_2.setText(_translate("MainWindow", "Signals"))
        self.plainTextEdit_ACMPlotDetails.setPlainText(_translate("MainWindow", "None"))
        self.groupBox.setTitle(_translate("MainWindow", "Select Excitation:"))
        self.radioButton_Excitation_Velocity.setText(_translate("MainWindow", "Velocity"))
        self.radioButton_Excitation_SweepFrequency.setText(_translate("MainWindow", "Sweep Frequency"))
        self.radioButton_Excitation_Position.setText(_translate("MainWindow", "Position"))
        self.groupBox_sweepFrequency.setTitle(_translate("MainWindow", "Settings"))
        self.radioButton_openLoop.setText(_translate("MainWindow", "Open loop"))
        self.radioButton_currentLoopOnly.setText(_translate("MainWindow", "Current Loop Only"))
        self.label_maxFreq2Sweep.setText(_translate("MainWindow", "Max Freq."))
        self.lineEdit_maxFreq2Sweep.setText(_translate("MainWindow", "200"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), _translate("MainWindow", "C-based Simulation"))
        self.pushButton_bodePlot.setText(_translate("MainWindow", "Bode Plot by Sweep Freuquency"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_6), _translate("MainWindow", "Bode Plot"))
        self.pushButton_getSignal.setText(_translate("MainWindow", "Generate\n"
"Signals"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("MainWindow", "Plots"))
        self.label.setText(_translate("MainWindow", "FEA Configuration     "))
        self.label_3.setText(_translate("MainWindow", "Machine Specification"))
        self.label_npd_5.setText(_translate("MainWindow", "Number of Poles"))
        self.label_npd_6.setText(_translate("MainWindow", "Rated Current [Arms]"))
        self.label_npd_7.setText(_translate("MainWindow", "Rated Power [W]"))
        self.label_npd_8.setText(_translate("MainWindow", "Rated Speed [rpm]"))
        self.label_npd_9.setText(_translate("MainWindow", "Output Folder Name"))
        self.lineEdit_npp_2.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedCurrent_2.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedPower_2.setText(_translate("MainWindow", "50000"))
        self.lineEdit_RatedSpeed_2.setText(_translate("MainWindow", "30000"))
        self.lineEdit_RatedSpeed_3.setText(_translate("MainWindow", "default/"))
        self.pushButton_updateModel_2.setText(_translate("MainWindow", "Run for Fun"))
        self.pushButton_updateModel_4.setText(_translate("MainWindow", "Start Optimization"))
        self.label__path2boptPython.setText(_translate("MainWindow", "Path to bopt-python"))
        self.lineEdit_path2boptPython.setText(_translate("MainWindow", "D:\\DrH\\bopt-python"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("MainWindow", "FEA-based Optimization (Under Development)"))
        self.menuLoad.setTitle(_translate("MainWindow", "Load"))
        self.menuTheme.setTitle(_translate("MainWindow", "Theme"))
        self.actionLocate.setText(_translate("MainWindow", "Json File"))
        self.actionDark.setText(_translate("MainWindow", "Dark"))
        self.actionLight.setText(_translate("MainWindow", "Light"))
# from consolewidget import ConsoleWidget
# from mplwidget import MplWidget
# from qcodeeditor import QCodeEditor


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
